********************
The sherpa.io module
********************

.. currentmodule:: sherpa.io

.. automodule:: sherpa.io

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      get_ascii_data
      read_arrays
      read_data
      write_arrays
      write_data
